@@ -45,6 +45,8 @@ class QA:
             self._describe()
         elif self._action == "update-quota":
             self._update_quota()
+        elif self._action == "toggle-maintenance":
+            self._toggle_maintenance()
 
     def _check(self):
         logger.info(
@@ -245,3 +247,6 @@ class QA:
         quota = prompt_utils.ask_questions_input("Insert new quota value: ")
 
         self._qainit.update_user_quota(username, quota)
+
+    def _toggle_maintenance(self):
+        self._qainit.maintenance()
