@@ -2,7 +2,6 @@
 import os
 import json
 import sys
-
 import yaml
 
 from suite_py.lib import logger
@@ -22,7 +21,7 @@ class Config:
         self._load()
 
     def _load(self):
-        with open(self._config_path_file) as configfile:
+        with open(self._config_path_file, encoding="utf-8") as configfile:
             conf = yaml.safe_load(configfile)
 
         conf["user"]["projects_home"] = os.path.join(
@@ -51,12 +50,16 @@ class Config:
             pass
 
     def put_cache(self, key, data):
-        with open(os.path.join(self._base_cache_path, key), "w") as cache_file:
+        with open(
+            os.path.join(self._base_cache_path, key), "w", encoding="utf-8"
+        ) as cache_file:
             json.dump(data, cache_file)
 
     def get_cache(self, key):
         try:
-            with open(os.path.join(self._base_cache_path, key)) as cache_file:
+            with open(
+                os.path.join(self._base_cache_path, key), encoding="utf-8"
+            ) as cache_file:
                 return json.load(cache_file)
         except Exception:
             logger.error(
@@ -68,7 +71,7 @@ class Config:
 def _load_local_config(conf):
     local_conf_path = os.path.join(os.curdir, ".suite_py.yml")
     try:
-        with open(local_conf_path) as f:
+        with open(local_conf_path, encoding="utf-8") as f:
             local_conf = yaml.safe_load(f)
 
             for key in conf.keys():
