@@ -188,6 +188,16 @@ class QainitHandler:
         logger.info("QA unfreezing initiated")
         logger.debug(json.dumps(r.json(), indent=2))
 
+    def maintenance(self):
+        r = self._execute("POST", "/api/v1/maintenance")
+        if r.json()["success"]:
+            maintenance = r.json()["maintenance"]
+            logger.info(
+                f"Maintenance mode is now {'enabled' if maintenance else 'disabled'}"
+            )
+
+        logger.debug(json.dumps(r.json(), indent=2))
+
     def _execute(self, request_method, api_endpoint, body=None):
         api_url = self.url + api_endpoint
         auth0_token = self._config.get_cache(f"{self.auth0_tenant}_auth0_token")
